CashuConfig class

Constructors

CashuConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

DOMAIN_SEPARATOR_HashToCurve → const String
FUNDING_CHECK_INTERVAL → const Duration
NETWORK_TIMEOUT → const Duration
Timeout for network requests to mint - fails fast if mint is offline
NUT_VERSION → const String
SPEND_CHECK_INTERVAL → const Duration