HttpRequestException class

Exception thrown when an HTTP request completes with a non-2xx status code.

Implemented types

Constructors

HttpRequestException({required int statusCode, required String body, required String url})
const

Properties

body → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited