computeFileHash abstract method

Stream<FileHashProgress> computeFileHash(
  1. String filePath
)

Computes SHA256 hash of a file by reading it in chunks Returns stream updates with progress and a final event containing FileHashProgress.hash

Implementation

Stream<FileHashProgress> computeFileHash(String filePath);