writeFileStream abstract method

Future<void> writeFileStream(
  1. String filePath,
  2. Stream<Uint8List> dataStream
)

Writes a stream of bytes to a file at the given path Creates the file if it doesn't exist, overwrites if it does

Implementation

Future<void> writeFileStream(String filePath, Stream<Uint8List> dataStream);