data_layer/io/file_io_platform library

Classes

FileIO
Platform-agnostic file I/O interface for reading and writing files Implementations use dart:io for native and dart:html for web
FileIONative
Stub implementation that should never be used The conditional exports should ensure the correct platform implementation is used
FileIOWeb
Stub implementation for web that should never be used

Functions

createFileIO() FileIO
Stub implementation used when neither dart:io nor web interop is available.