data_layer/io/file_io_stub library

Classes

FileIONative
Stub implementation that should never be used The conditional exports should ensure the correct platform implementation is used
FileIOWeb
Stub implementation for web that should never be used