computeFileHash method

  1. @override
Stream<FileHashProgress> computeFileHash(
  1. String filePath
)
override

Computes SHA256 hash of a file by reading it in chunks Returns stream updates with progress and a final event containing FileHashProgress.hash

Implementation

@override
Stream<FileHashProgress> computeFileHash(String filePath) {
  throw UnimplementedError();
}