Nip05Model class

model for converting json <==> dart object

Inheritance
Available extensions

Constructors

Nip05Model({required String pubKey, required String nip05, bool valid = false, int? networkFetchTime, List<String>? relays = const []})
creates a new Nip05Model instance

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkFetchTime ↔ int?
getter/setter pairinherited
nip05 ↔ String
getter/setter pairinherited
pubKey ↔ String
getter/setter pairinherited
relays ↔ List<String>?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valid ↔ bool
getter/setter pairinherited

Methods

copyWith({String? pubKey, String? nip05, bool? valid, int? networkFetchTime, List<String>? relays}) → Nip05
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonForStorage() → Map<String, Object?>

Available on Nip05, provided by the Nip05Extension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited