CashuWalletTransactionModel class

Inheritance
Available extensions

Constructors

CashuWalletTransactionModel({required String id, required String walletId, required int changeAmount, required String unit, required WalletType walletType, required WalletTransactionState state, required String mintUrl, String? completionMsg, int? transactionDate, int? initiatedDate, String? note, String? method, CashuQuote? qoute, CashuQuoteMelt? qouteMelt, List<CahsuKeyset>? usedKeysets, String? token, List<String>? proofPubKeys, Map<String, dynamic>? metadata})
CashuWalletTransactionModel.fromEntity(CashuWalletTransaction transaction)
factory
CashuWalletTransactionModel.fromJson(Map<String, dynamic> json)
factory

Properties

changeAmount int
positive for incoming, negative for outgoing
finalinherited
completionMsg String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
initiatedDate int?
Date in milliseconds since epoch
getter/setter pairinherited
metadata Map<String, dynamic>
metadata to store additional information for the specific transaction type
finalinherited
method String?
getter/setter pairinherited
mintUrl String
getter/setter pairinherited
note String?
getter/setter pairinherited
proofPubKeys List<String>?
getter/setter pairinherited
qoute CashuQuote?
getter/setter pairinherited
qouteMelt CashuQuoteMelt?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state WalletTransactionState
finalinherited
token String?
getter/setter pairinherited
transactionDate int?
Date in milliseconds since epoch
getter/setter pairinherited
unit String
finalinherited
usedKeysets List<CahsuKeyset>?
getter/setter pairinherited
walletId String
finalinherited
walletType WalletType
finalinherited

Methods

copyWith({String? id, String? walletId, int? changeAmount, String? unit, WalletType? walletType, WalletTransactionState? state, String? mintUrl, String? note, String? method, CashuQuote? qoute, CashuQuoteMelt? qouteMelt, List<CahsuKeyset>? usedKeysets, int? transactionDate, int? initiatedDate, String? completionMsg, String? token, List<String>? proofPubKeys}) CashuWalletTransaction
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJsonForStorage() Map<String, Object?>

Available on WalletTransaction, provided by the WalletTransactionExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited