LnurlWalletTransactionModel class

Inheritance
Available extensions

Constructors

LnurlWalletTransactionModel({required String id, required String walletId, required int changeAmount, required String unit, required WalletType walletType, required WalletTransactionState state, required Map<String, dynamic> metadata, String? completionMsg, int? transactionDate, int? initiatedDate})
LnurlWalletTransactionModel.fromEntity(LnurlWalletTransaction transaction)
factory
LnurlWalletTransactionModel.fromJson(Map<String, dynamic> json)
factory

Properties

changeAmount → int
positive for incoming, negative for outgoing
finalinherited
completionMsg → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
initiatedDate ↔ int?
Date in milliseconds since epoch
getter/setter pairinherited
metadata → Map<String, dynamic>
metadata to store additional information for the specific transaction type
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → WalletTransactionState
finalinherited
transactionDate ↔ int?
Date in milliseconds since epoch
getter/setter pairinherited
unit → String
finalinherited
walletId → String
finalinherited
walletType → WalletType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toJsonForStorage() → Map<String, Object?>

Available on WalletTransaction, provided by the WalletTransactionExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited