WalletTransactionModel class

A helper model for wallet transaction JSON serialization and deserialization.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromEntity(WalletTransaction transaction) WalletTransaction
Converts a domain transaction into the corresponding model variant.
fromJson(Map<String, dynamic> json) WalletTransaction
Deserializes a wallet transaction from JSON.
toJson(WalletTransaction transaction) Map<String, dynamic>
Converts a domain wallet transaction to a serializable JSON map.