addEventSource method
Adds one provenance relay for a stored event.
Provenance is intentionally stored separately from broadcast delivery targets. A relay can be a source of truth for where an event was observed without being a relay NDK should later broadcast back to.
Implementation
@override
Future<void> addEventSource({
required String eventId,
required String relayUrl,
}) async {
eventSources[_eventSourceKey(eventId, relayUrl)] = relayUrl;
}