Nip05HttpRepositoryImpl class

implementation of the Nip05Repository interface with http

Implemented types

Constructors

Nip05HttpRepositoryImpl({required HttpRequestDS httpDS, Duration timeout = NIP_05_REQUEST_TIMEOUT})
creates a new Nip05HttpRepositoryImpl instance

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpDS → HttpRequestDS
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → Duration
how long to wait for a nostr.json response
final

Methods

fetchNip05(String nip05) → Future<Nip05?>
fetches NIP-05 data without validation returns pubkey and relays for the given nip05 identifier
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestNip05(String nip05, String pubkey) → Future<Nip05?>
network request to get the Nip05 object
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited