timeout property
deadline covering connection setup and the entire response body, so a stalled relay does not retain an HTTP socket
Implementation
final Duration timeout;
deadline covering connection setup and the entire response body, so a stalled relay does not retain an HTTP socket
final Duration timeout;