RustEventVerifier class

Stub implementation of RustEventVerifier for platforms that don't support FFI (e.g., web).

This class throws UnsupportedError for all operations since Rust FFI is not available on web platforms.

Implemented types

Constructors

RustEventVerifier()
Creates a new instance of RustEventVerifier.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(Nip01Event event) Future<bool>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited