Account class

Account entity

Constructors

Account({required AccountType type, required String pubkey, required EventSigner signer})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pendingRequests → List<PendingSignerRequest>
Current list of pending signer requests (synchronous snapshot).
no setter
pendingRequestsStream → Stream<List<PendingSignerRequest>>
Stream of pending signer requests waiting for user approval.
no setter
pubkey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signer → EventSigner
final
type → AccountType
final

Methods

cancelRequest(String requestId) → bool
Cancel a pending request by its ID.
dispose() → Future<void>
Dispose of resources used by the signer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited