dispose method
Dispose of resources used by the signer.
Call this when the account is no longer needed to avoid memory leaks.
Implementation
Future<void> dispose() => signer.dispose();
Dispose of resources used by the signer.
Call this when the account is no longer needed to avoid memory leaks.
Future<void> dispose() => signer.dispose();