AuthPolicy.allow constructor

const AuthPolicy.allow(
  1. Account account
)

Starts anonymous and moves to a connection bound to account only once a relay refused the request without an identity.

Implementation

const factory AuthPolicy.allow(Account account) = AuthPolicyAllow;