AuthPolicyAllow class

Authenticates as account once refused, see AuthPolicy.allow.

Inheritance

Constructors

AuthPolicyAllow(Account account)
authenticates as account once refused
const

Properties

account → Account
identity this may authenticate as, null when it never authenticates
final
canonical → String
stable representation, for logs and for telling two requests apart
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override