BlobUploadProgress class

Progress information for blob uploads

Constructors

BlobUploadProgress({required String currentServer, required int sentBytes, required int totalBytes, required List<BlobUploadResult> completedUploads, UploadPhase phase = UploadPhase.uploading, double? progressPhase, int? mirrorsTotal, int? mirrorsCompleted, bool isComplete = false})

Properties

completedUploads List<BlobUploadResult>
final
currentServer String
final
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
final
mirrorsCompleted int
final
mirrorsTotal int
final
percentage double
no setter
percentagePhase double
final
phase UploadPhase
final
progress double
Overall progress mapped across fixed phases: hashing: 0-33%, uploading: 33-66%, mirroring: 66-100%
no setter
progressPhase double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentBytes int
final
totalBytes int
final
uploadProgress double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited