domain_layer/entities/blossom_authorization library

Classes

BlossomAuthorization
What a blossom operation does about the Authorization header, and when.
BlossomAuthorizationNone
Never authorises, see BlossomAuthorization.none.
BlossomAuthorizationOnRefusal
Authorises once refused, see BlossomAuthorization.onRefusal.
BlossomAuthorizationUpfront
Authorises from the first request, see BlossomAuthorization.upfront.

Typedefs

BlossomAuthorizationConsent = Future<bool> Function(String serverUrl)
Whether serverUrl may be sent the signed event, see AuthHandler.
BlossomAuthorizationSigner = Future<Nip01Event> Function()
Signs the kind 24242 event an operation authorises itself with.