addError method
Add an error to the broadcast state stream and dispose
Implementation
void addError(Object error, [StackTrace? stackTrace]) {
_stateUpdatesController.addError(error, stackTrace);
_dispose();
}
Add an error to the broadcast state stream and dispose
void addError(Object error, [StackTrace? stackTrace]) {
_stateUpdatesController.addError(error, stackTrace);
_dispose();
}