EvictionResult class

Summary returned from one eviction run.

Constructors

EvictionResult({required int removedEvents, int removedExpired = 0, int removedDeleted = 0, int removedSuperseded = 0, int removedDeliveredEphemeral = 0, int removedByKindCap = 0, int keptDueToDeliveryState = 0, int keptProtected = 0, int removedCompletedDeliveries = 0, int removedTerminalFailedDeliveries = 0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keptDueToDeliveryState int
final
keptProtected int
final
removedByKindCap int
final
removedCompletedDeliveries int
Standalone delivery records swept because they were delivered and aged past EvictionPolicy.completedDeliveryRetention.
final
removedDeleted int
final
removedDeliveredEphemeral int
final
removedEvents int
final
removedExpired int
final
removedSuperseded int
final
removedTerminalFailedDeliveries int
Standalone delivery records swept because they terminally failed and aged past EvictionPolicy.terminalFailedDeliveryRetention.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? removedEvents, int? removedExpired, int? removedDeleted, int? removedSuperseded, int? removedDeliveredEphemeral, int? removedByKindCap, int? keptDueToDeliveryState, int? keptProtected, int? removedCompletedDeliveries, int? removedTerminalFailedDeliveries}) EvictionResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const EvictionResult