FileHashProgress class
Constructors
- FileHashProgress({required int processedBytes, required int totalBytes, bool isComplete = false, String? hash})
Properties
- hash → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
final
- percentage → double
-
no setter
- processedBytes → int
-
final
- progress → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBytes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited