RelayJitAssignedPubkey class

Represents a relay jit assigned pubkey

Constructors

RelayJitAssignedPubkey(String pubkey, ReadWriteMarker direction)
Creates a new relay jit assigned pubkey

Properties

direction → ReadWriteMarker
direction the assignment
final
hashCode → int
The hash code for this object.
no setterinherited
pubkey → String
hex pubkey
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited