setCustomField method

void setCustomField(
  1. String key,
  2. dynamic value
)

Set a custom field in the content Works for both known fields (name, display_name, etc.) and custom fields

Implementation

void setCustomField(String key, dynamic value) {
  content[key] = value;

  // Update cached fields if this is a known property
  switch (key) {
    case 'name':
      _name = value as String?;
      break;
    case 'display_name':
      _displayName = value as String?;
      break;
    case 'picture':
      _picture = value as String?;
      break;
    case 'banner':
      _banner = value as String?;
      break;
    case 'website':
      _website = value as String?;
      break;
    case 'about':
      _about = value as String?;
      break;
    case 'nip05':
      _nip05 = value as String?;
      break;
    case 'lud16':
      _lud16 = value as String?;
      break;
    case 'lud06':
      _lud06 = value as String?;
      break;
  }
}