Naddr class

Represents a decoded naddr (addressable event coordinate)

Constructors

Naddr({required String identifier, required String pubkey, required int kind, List<String>? relays})

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → String
final
kind → int
final
pubkey → String
final
relays → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited