Nevent class

Represents a decoded nevent (event reference)

Constructors

Nevent({required String eventId, String? author, int? kind, List<String>? relays})

Properties

author → String?
final
eventId → String
final
hashCode → int
The hash code for this object.
no setterinherited
kind → int?
final
relays → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited