Nip46ClientMetadata class

Constructors

Nip46ClientMetadata({String? name, String? url, String? image, List<String>? perms})
const

Properties

displayInfo → Map<String, String>
NIP-46 optional_client_metadata, keys shared with nostrconnect://
no setter
hashCode → int
The hash code for this object.
no setterinherited
image → String?
final
name → String?
final
perms → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited