Nip17EncryptedFile class
AES-GCM encrypted bytes and the private metadata required by a NIP-17 kind-15 rumor.
Constructors
Properties
- ciphertext → Uint8List
-
final
- encryptedSha256 → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- nonce → String
-
final
- originalSha256 → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited