NostrMessageRaw class
Constructors
- NostrMessageRaw({required NostrMessageRawType type, Nip01Event? nip01Event, String? requestId, dynamic otherData})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nip01Event → Nip01Event?
-
final
- otherData → dynamic
-
final
- requestId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → NostrMessageRawType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited