PendingSignerRequest class

Represents a pending request waiting for user approval on a signer.

This is used by signers that require human approval (NIP-46 bunkers, NIP-07 browser extensions, Amber, etc.) to expose their pending operations to the UI.

Constructors

PendingSignerRequest({required String id, required SignerMethod method, required DateTime createdAt, required String signerPubkey, Nip01Event? event, String? plaintext, String? ciphertext, String? counterpartyPubkey})

Properties

ciphertext String?
The ciphertext being decrypted (only for decrypt methods)
final
content String?
Returns plaintext or ciphertext depending on the method. For encrypt methods, returns plaintext. For decrypt methods, returns ciphertext.
no setter
counterpartyPubkey String?
The counterparty public key (for encrypt/decrypt operations)
final
createdAt DateTime
When this request was created
final
event Nip01Event?
The event being signed (only for SignerMethod.signEvent)
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this request
final
method SignerMethod
The method being called
final
plaintext String?
The plaintext being encrypted (only for encrypt methods)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signerPubkey String
The public key of the signer (the account making the request)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited