PubkeyMapping class

maps the direction for a pubkey read, write, both

Available extensions

Constructors

PubkeyMapping({required String pubKey, required ReadWriteMarker rwMarker})

Properties

hashCode → int
The hash code for this object.
no setteroverride
pubKey ↔ String
pub key
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rwMarker ↔ ReadWriteMarker
read write marker
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonForStorage() → Map<String, Object?>

Available on PubkeyMapping, provided by the PubkeyMappingExtension extension

toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override