ReadWriteMarker enum

nip65 read/write marker

Inheritance
Available extensions

Values

readOnly → const ReadWriteMarker
writeOnly → const ReadWriteMarker
readWrite → const ReadWriteMarker

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isRead → bool
no setter
isWrite → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isPartialMatch(ReadWriteMarker other) → bool
Returns true if this marker is a subset of the other marker. returns true for readOnly == readWrite and writeOnly == readWrite
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonForStorage() → Map<String, Object?>

Available on ReadWriteMarker, provided by the ReadWriteMarkerExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from({required bool read, required bool write}) → ReadWriteMarker

Constants

values → const List<ReadWriteMarker>
A constant List of the values in this enum, in order of their declaration.