Relay class

Basic relay info/status

Constructors

Relay({required String url, required ConnectionSource connectionSource})
default constructor

Properties

connecting ↔ bool
is it connecting
getter/setter pair
connectionSource ↔ ConnectionSource
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastConnectTry ↔ int?
last connection try timestamp
getter/setter pair
lastSuccessfulConnect ↔ int?
last successful connection
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String
relay url
getter/setter pair

Methods

failedToConnect() → void
mark as failed to connect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
succeededToConnect() → void
mark as succeded to connect
toString() → String
A string representation of this object.
inherited
tryingToConnect() → void
set trying to connect
wasLastConnectTryLongerThanSeconds(int seconds) → bool
was last connection try longer than given seconds

Operators

operator ==(Object other) → bool
The equality operator.
inherited