RelayAuth.allow constructor

const RelayAuth.allow(
  1. Account account
)

Starts anonymous and moves to a connection bound to account only once a relay refused the request without an identity.

Implementation

const factory RelayAuth.allow(Account account) = RelayAuthAllow;