account property
Account?
get
account
identity this may authenticate as, null when it never authenticates
Implementation
Account? get account;
identity this may authenticate as, null when it never authenticates
Account? get account;