RelayAuthNever class

Never authenticates, see RelayAuth.never.

Inheritance

Constructors

RelayAuthNever()
never authenticates
const

Properties

account Account?
identity this may authenticate as, null when it never authenticates
no setteroverride
canonical String
stable representation, for logs and for telling two requests apart
no setteroverride
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override