RelaySet class

Available extensions

Constructors

RelaySet({required String name, required String pubKey, int relayMinCountPerPubkey = 0, required Map<String, List<PubkeyMapping>> relaysMap, List<NotCoveredPubKey> notCoveredPubkeys = const [], required RelayDirection direction, bool fallbackToBootstrapRelays = true})

Properties

direction ↔ RelayDirection
getter/setter pair
fallbackToBootstrapRelays ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
name ↔ String
getter/setter pair
notCoveredPubkeys ↔ List<NotCoveredPubKey>
getter/setter pair
pubKey ↔ String
getter/setter pair
relayMinCountPerPubkey ↔ int
getter/setter pair
relaysMap ↔ Map<String, List<PubkeyMapping>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urls → Iterable<String>
no setter

Methods

addMoreRelays(Map<String, List<PubkeyMapping>> more) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
splitIntoRequests(Filter filter, RequestState groupRequest) → void
toJsonForStorage() → Map<String, Object?>

Available on RelaySet, provided by the RelaySetExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildId(String name, String pubKey) → String
sliceFilterAuthors(Filter filter) → List<Filter>

Constants

kMaxAuthorsPerRequest → const int