RelayRequestState class

Single relay request state

Constructors

RelayRequestState(RelayConnectionKey key, List<Filter> filters)
default const

Properties

filters List<Filter>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key RelayConnectionKey
connection this request was sent on
final
receivedClosed bool
getter/setter pair
receivedEOSE bool
getter/setter pair
retryingAuth bool
set while this connection authenticates to satisfy the request: the relay closed it, but it is on its way back and must not count as finished
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url of the relay this request was sent to
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited