SignerRequestRejectedException class

Exception thrown when a signer request is rejected by the remote signer.

This occurs when the user explicitly rejects/denies the request on the remote signer (bunker, browser extension, NIP-55 signer app, etc.).

Implemented types

Constructors

SignerRequestRejectedException({String? requestId, String? originalMessage})

Properties

hashCode → int
The hash code for this object.
no setterinherited
originalMessage → String?
The original error message from the remote signer
final
requestId → String?
The ID of the request that was rejected (if available)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited