UserRelayList class

Available extensions

Constructors

UserRelayList({required String pubKey, required Map<String, ReadWriteMarker> relays, required int createdAt, required int refreshedTimestamp})

Properties

createdAt ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pubKey ↔ String
getter/setter pair
readUrls → Iterable<String>
no setter
refreshedTimestamp ↔ int
getter/setter pair
relays ↔ Map<String, ReadWriteMarker>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urls → Iterable<String>
no setter
writeUrls → Iterable<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonForStorage() → Map<String, Object?>

Available on UserRelayList, provided by the UserRelayListExtension extension

toNip65() → Nip65
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited