initialize abstract method
Initializes the wallet (e.g., establishes connections) Called when wallet is first loaded or activated Returns an updated wallet if initialization resulted in changes, null otherwise
Implementation
Future<Wallet?> initialize(Wallet wallet);