send abstract method
Pays a Lightning invoice using this wallet Returns payment result with preimage and fees
Implementation
Future<PayInvoiceResponse> send(Wallet wallet, String invoice);
Pays a Lightning invoice using this wallet Returns payment result with preimage and fees
Future<PayInvoiceResponse> send(Wallet wallet, String invoice);