WalletTransactionState enum

Inheritance
Available extensions

Values

draft → const WalletTransactionState

pending states draft requires user confirmation

const WalletTransactionState('DRAFT')
pending → const WalletTransactionState

payment is in flight

const WalletTransactionState('PENDING')
completed → const WalletTransactionState

done states transaction went through

const WalletTransactionState('SUCCESS')
canceled → const WalletTransactionState

canceld by user - usually a canceld draft, or not sufficient funds

const WalletTransactionState('CANCELED')
failed → const WalletTransactionState

transaction failed

const WalletTransactionState('FAILED')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isDone → bool
no setter
isPending → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<WalletTransactionState>
A constant List of the values in this enum, in order of their declaration.