evict abstract method
Run one eviction pass according to policy.
Backends should remove associated sidecars, provenance, and delivery state for any event they physically delete.
Implementation
Future<EvictionResult> evict(EvictionPolicy policy);
Run one eviction pass according to policy.
Backends should remove associated sidecars, provenance, and delivery state for any event they physically delete.
Future<EvictionResult> evict(EvictionPolicy policy);