removeContactList abstract method

  1. @Deprecated('Use removeEvents(pubKeys: ..., kinds: [ContactList.kKind]); ContactList is now a convenience view over the generic event cache.')
Future<void> removeContactList(
  1. String pubKey
)

Implementation

@Deprecated(
  'Use removeEvents(pubKeys: ..., kinds: [ContactList.kKind]); ContactList is now a convenience view over the generic event cache.',
)
Future<void> removeContactList(String pubKey);