removeMetadata abstract method

  1. @Deprecated('Use removeEvents(pubKeys: ..., kinds: [Metadata.kKind]); Metadata is now a convenience view over the generic event cache.')
Future<void> removeMetadata(
  1. String pubKey
)

Implementation

@Deprecated(
  'Use removeEvents(pubKeys: ..., kinds: [Metadata.kKind]); Metadata is now a convenience view over the generic event cache.',
)
Future<void> removeMetadata(String pubKey);