WalletsRepo class abstract

Repository for wallet storage operations Thin abstraction over CacheManager for wallet persistence

Implementers

Constructors

WalletsRepo()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDefaultWalletIdForReceiving() String?
Get default wallet for sending funds (e.g. for paying invoices)
getDefaultWalletIdForSending() String?
Get default wallet for receiving funds (e.g. for generating invoices)
getTransactions({int? limit, int? offset, String? walletId, String? unit, WalletType? walletType}) Future<List<WalletTransaction>>
Get transactions with optional filtering
getWallet(String id) Future<Wallet>
Get a specific wallet by ID
getWallets({List<String>? ids}) Future<List<Wallet>>
Get wallets by id return all if ids is null
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeWallet(String id) Future<void>
Remove a wallet by ID
saveTransactions(List<WalletTransaction> transactions) Future<void>
Save transactions to storage
setDefaultWalletForReceiving(String? walletId) → void
Set default wallet for receiving funds (e.g. for generating invoices)
setDefaultWalletForSending(String? walletId) → void
Set default wallet for sending funds (e.g. for paying invoices)
storeWallet(Wallet account) Future<void>
Store a wallet
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited