CacheWrite class

Writes network-delivered events into the cache.

Network responses enter the same generic event store used by event reads, replaceable convergence, deletion suppression, and convenience projections.

Constructors

CacheWrite(CacheManager cacheManager)

Properties

cacheManager CacheManager
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveNetworkResponse({required bool writeToCache, required Stream<Nip01Event> inputStream}) → void
Persists network responses when writeToCache is enabled.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited