Connectivy class

get connectivity status
& update ndk about your application connectivity for faster reconnects

Constructors

Connectivy(RelayManager _relayManager)

Properties

hashCode int
The hash code for this object.
no setterinherited
relayConnectivityChanges Stream<List<RelayConnectivity>>
streams connectivity status of every connection
a relay can hold several, so group by RelayConnectivity.url if needed
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tryReconnect() Future<void>
forces all relays to reconnect
use this for faster reconnects based on your application/os connectivity \

Operators

operator ==(Object other) bool
The equality operator.
inherited