upload method
Future<List<BlobUploadResult> >
upload({
- required NdkFile file,
- List<
String> ? serverUrls, - bool serverMediaOptimisation = false,
- AuthPolicy? auth,
upload a file to the server(s)
if serverUrls is null, the userServerList is fetched from nostr.
if no serverUrls (param or nostr) are found, throws an error
serverMediaOptimisation is whether the server should optimise the media BUD-05, IMPORTANT: the server hash will be different
auth says which identity the upload may be attributed to, see
AuthPolicy.
Implementation
Future<List<BlobUploadResult>> upload({
required NdkFile file,
List<String>? serverUrls,
bool serverMediaOptimisation = false,
AuthPolicy? auth,
}) {
return _blossom.uploadBlob(
data: file.data,
serverUrls: serverUrls,
contentType: file.mimeType,
serverMediaOptimisation: serverMediaOptimisation,
auth: auth,
);
}