Unwraps a gift-wrapped event to retrieve the original rumor giftWrap the gift-wrapped event to unwrap customSigner optional signer to use instead of the logged-in account's signer returns the original rumor event
converts a Nip01Event to a giftWrap Nip01Event rumor the event you want to wrap recipientPubkey the reciever of the rumor customSigner optional signer to use instead of the logged-in account's signer returns the wrapped event