Nip05Usecase class

usecase to handle Nip05 operations (verify and fetch)

Constructors

Nip05Usecase({required CacheManager database, required Nip05Repository nip05Repository})
creates a new Nip05Usecase instance _database the cache manager _nip05Repository the nip05 repository

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

check({required String nip05, required String pubkey}) Future<Nip05>
checks the nip05 object for validity it checks the cache first, if not found it fetches from the network if either fails valid is set to false
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String nip05) Future<Nip05?>
resolves NIP-05 data without requiring a pubkey for validation returns the Nip05 object with pubkey and relays
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited