ErrorCode enum

Inheritance
Available extensions

Values

badRequest → const ErrorCode
const ErrorCode('BAD_REQUEST', 'The request contains an invalid parameter.')
unsupportedPaymentInstruction → const ErrorCode
const ErrorCode('UNSUPPORTED_PAYMENT_INSTRUCTION', 'The wallet cannot select a supported payment instruction.')
unsupportedNetwork → const ErrorCode
const ErrorCode('UNSUPPORTED_NETWORK', 'The payment instruction uses a different Bitcoin network.')
rateLimited → const ErrorCode
const ErrorCode('RATE_LIMITED', 'The client is sending commands too fast. It should retry in a few seconds.')
notImplemented → const ErrorCode
const ErrorCode('NOT_IMPLEMENTED', 'The command is not known or is intentionally not implemented.')
insufficientBalance → const ErrorCode
const ErrorCode('INSUFFICIENT_BALANCE', 'The wallet does not have enough funds to cover a fee reserve or the payment amount.')
paymentFailed → const ErrorCode
const ErrorCode('PAYMENT_FAILED', 'The payment failed. This may be due to a timeout, exhausting all routes, insufficient capacity or similar.')
notFound → const ErrorCode
const ErrorCode('NOT_FOUND', 'The invoice could not be found by the given parameters.')
quotaExceeded → const ErrorCode
const ErrorCode('QUOTA_EXCEEDED', 'The wallet has exceeded its spending quota.')
restricted → const ErrorCode
const ErrorCode('RESTRICTED', 'This public key is not allowed to do this operation.')
unauthorized → const ErrorCode
const ErrorCode('UNAUTHORIZED', 'This public key has no wallet connected.')
internal → const ErrorCode
const ErrorCode('INTERNAL', 'An internal error.')
feeLimitExceeded → const ErrorCode
const ErrorCode('FEE_LIMIT_EXCEEDED', 'No route fit the max_fee budget and no payment was attempted.')
other → const ErrorCode
const ErrorCode('OTHER', 'Other error.')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
message → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ErrorCode>
A constant List of the values in this enum, in order of their declaration.