isConnectionOpen method
checks if the connection identified by key is open
Implementation
bool isConnectionOpen(RelayConnectionKey key) =>
globalState.relays[key]?.relayTransport?.isOpen() ?? false;
checks if the connection identified by key is open
bool isConnectionOpen(RelayConnectionKey key) =>
globalState.relays[key]?.relayTransport?.isOpen() ?? false;