clear method

void clear()

Removes all verification state.

Verifications started before this call may still complete for their existing listeners, but cannot repopulate this cache.

Implementation

void clear() {
  _generation++;
  _verified.clear();
  _verificationInFlight.clear();
}