VerifyEventStream class

Constructors

VerifyEventStream({required Stream<Nip01Event> unverifiedStreamInput, required EventVerifier eventVerifier, int maxConcurrent = 100, VerifiedEventMemCache? verifiedEventCache})

Properties

eventVerifier → EventVerifier
final
hashCode → int
The hash code for this object.
no setterinherited
maxConcurrent → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unverifiedStreamInput → Stream<Nip01Event>
final

Methods

call() → Stream<Nip01Event>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited