Software class

Constructors

Software({required Requests requests})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApp({required SoftwareAppRef app, Iterable<String>? relays, Duration? timeout}) Future<SoftwareApp?>
getReleases({required SoftwareAppRef app, String channel = 'main', Iterable<String>? relays, Duration? timeout}) Future<List<SoftwareRelease>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveAssets(SoftwareRelease release, {Iterable<String>? relays, Duration? timeout}) Future<List<SoftwareAsset>>
resolveAssetsForReleases(Iterable<SoftwareRelease> releases, {Iterable<String>? relays, Duration? timeout}) Future<Map<String, List<SoftwareAsset>>>
Resolves assets for multiple releases with one relay query.
selectLatestCompatible({required List<SoftwareRelease> releases, required Map<String, List<SoftwareAsset>> assetsByReleaseId, required InstalledSoftware installed}) SoftwareUpdate?
selectUpdate({required List<SoftwareRelease> releases, required Map<String, List<SoftwareAsset>> assetsByReleaseId, required InstalledSoftware installed}) SoftwareUpdate?
toString() String
A string representation of this object.
inherited
watchReleases({required SoftwareAppRef app, String channel = 'main', Iterable<String>? relays}) Stream<List<SoftwareRelease>>

Operators

operator ==(Object other) bool
The equality operator.
inherited