entities library

exports all entities, intended usage: import 'package:ndk/entities.dart' as ndk_entities;

Classes

Account
Account entity
BlobDeleteResult
Result of a blob delete
BlobDescriptor
Descriptor of a blob - when getting a blob from a server
BlobNip94
BUD-08
is BlobNip94 because fromJson does not work with nostr events, only blobDescriptor!
BlobResponse
Response of a blob download
BlobUploadProgress
Progress information for blob uploads
BlobUploadResult
Result of a blob upload
BroadcastState
hold state information for a broadcast
CahsuKeyset
CahsuKeysetResponse
CahsuKeysResponse
CahsuMintKeyPair
CashuBlindedMessage
CashuBlindedMessageItem
CashuBlindedSignature
CashuMintCachedEndpoint
CashuMintContact
CashuMintInfo
CashuMintNut
CashuMintPaymentMethod
CashuProof
CashuRestoreKeysetResult
Result of a restore operation for a single keyset
CashuRestoreResult
CashuToken
CashuUserSeedphrase
CashuWallet
Cashu wallet implementation Stores mint information and handles Cashu-specific wallet operations
CashuWalletProvider
Provider for Cashu wallets Implements factory and operations for Cashu mint-based wallets
CashuWalletTransaction
ContactList
nip02 contact list
EventFilter
A class that filters events
Used to clean event streams based on the event
FileHashProgress
Filter
Represents a filter for querying Nostr events.
GlobalState
Global state of the NDK as a user you should not need to interact with this class
you should use the NDK API and keep the global state in memory
LnurlWallet
LNURL wallet implementation for read-only/receive-only operations Stores LNURL-pay endpoint configuration and generates invoices for receiving payments
LnurlWalletProvider
Provider for LNURL wallets Implements receive-only functionality for LNURL-pay endpoints Supports user@domain.com format only
LnurlWalletTransaction
Metadata
basic nostr metadata
NdkBroadcastResponse
the response to a low level broadcast request
NdkFile
NdkResponse
Represents a response from a Nostr Development Kit (NDK) request.
Nip01Event
basic nostr nip01 event data structure
Nip01EventModel
Data model for NIP-01 Event Extends Nip01Event entity with serialization methods to/from JSON and other formats
Nip05
domain identifier entity
Nip51List
Nip51ListElement
Nip51Set
Nip65
NotCoveredPubKey
NwcWallet
NWC (Nostr Wallet Connect) wallet implementation Manages connection to a remote wallet via NWC protocol
NwcWalletProvider
Provider for NWC wallets Implements factory and operations for Nostr Wallet Connect wallets
NwcWalletTransaction
PubkeyMapping
maps the direction for a pubkey read, write, both
Relay
Basic relay info/status
RelayBroadcastResponse
hols information about a individual relay broadcast response
e.g.
"OK", "b1a649ebe8...", true, "duplicate: already have this event" "OK", "b1a649ebe8...", false, "pow: difficulty 26 is less than 30"
RelayConnectivity<T>
Represents the connectivity of a relay.
RelayInfo
RelayRequestState
Single relay request state
RelaySet
RelayStats
relay stats
RequestState
State per request for multiple relays
Tuple<T, U>
Tuple class to hold two values
UserRelayList
Wallet
Base interface for all wallet types Provides common properties and methods that all wallets must implement
WalletBalance
WalletFactory
Factory for deserializing wallets from storage Storage packages use this to convert stored data back to Wallet objects Each wallet type implements a static fromStorage method that handles its specific deserialization
WalletProvider
Unified interface for wallet providers Combines factory pattern with wallet operations Each wallet type implements this interface
Wallets
Unified wallet system that handles multiple wallet types (NWC, Cashu, etc.) Uses WalletProvider pattern for pluggability
WalletTransaction

Enums

AccountType
CashuProofState
ConnectionSource
Language
BIP39: Since the vast majority of BIP39 wallets supports only the English wordlist, it is strongly discouraged to use non-English wordlists for generating the mnemonic sentences. If you still feel your application really needs to use a localized wordlist, use one of the following instead of inventing your own.
MnemonicLength
ReadWriteMarker
nip65 read/write marker
RelayDirection
UploadPhase
UploadStrategy
WalletTransactionState
WalletType