Language enum

BIP39: Since the vast majority of BIP39 wallets supports only the English wordlist, it is strongly discouraged to use non-English wordlists for generating the mnemonic sentences. If you still feel your application really needs to use a localized wordlist, use one of the following instead of inventing your own.

Inheritance
Available extensions

Values

english → const Language
const Language('english', englishList)
french → const Language
const Language('french', frenchList)
spanish → const Language
const Language('spanish', spanishList)
italian → const Language
const Language('italian', italianList)
portuguese → const Language
const Language('portuguese', portugueseList)
czech → const Language
const Language('czech', czechList)
korean → const Language
const Language('korean', koreanList)
simplifiedChinese → const Language
const Language('chinese-simplified', simplifiedChineseList)
traditionalChinese → const Language
const Language('chinese-traditional', traditionalChineseList)
japanese → const Language
const Language('japanese', japaneseList)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
label → String
final
list → List<String>
no setter
map → Map<int, String>
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separator → String
no setter

Methods

isValid(String word) → bool
isValid function formats input (NFKD) and check his existence in the current language wordlist
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Language>
A constant List of the values in this enum, in order of their declaration.