MnemonicLength enum

Inheritance
Available extensions

Values

words12 → const MnemonicLength
const MnemonicLength(entropy: 128, words: 12, checksum: 4)
words15 → const MnemonicLength
const MnemonicLength(entropy: 160, words: 15, checksum: 5)
words18 → const MnemonicLength
const MnemonicLength(entropy: 192, words: 18, checksum: 6)
words21 → const MnemonicLength
const MnemonicLength(entropy: 224, words: 21, checksum: 7)
words24 → const MnemonicLength
const MnemonicLength(entropy: 256, words: 24, checksum: 8)

Properties

bytes → int
no setter
checksum → int
final
entropy → int
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
words → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

availableBits → List<int>
no setter
availableWords → List<int>
no setter

Static Methods

fromEntropy(int entropy) → MnemonicLength
fromWords(int wordCount) → MnemonicLength

Constants

values → const List<MnemonicLength>
A constant List of the values in this enum, in order of their declaration.