cacheEvictionStartupDelay property
Delay before the first scheduled cache eviction run after startup.
Implementation
Duration cacheEvictionStartupDelay;
Delay before the first scheduled cache eviction run after startup.
Duration cacheEvictionStartupDelay;