runCacheEvictionOnStartup property
Whether to run cache eviction once on startup before periodic runs.
Implementation
bool runCacheEvictionOnStartup;
Whether to run cache eviction once on startup before periodic runs.
bool runCacheEvictionOnStartup;