IsolatePool class

Constructors

IsolatePool()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isolates → List<IsolateConfig>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(IsolateConfig config) → void
getNextSendPort() → SendPort
killAll() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited