LogColor class

ANSI color codes for terminal output

Constructors

LogColor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

colorize(String text, String color) → String
Wrap text with color
colorizeLevel(LogLevel level, String text) → String
Colorize message based on log level
forLevel(LogLevel level) → String
Get color for log level

Constants

black → const String
blue → const String
cyan → const String
gray → const String
green → const String
magenta → const String
red → const String
reset → const String
white → const String
yellow → const String