Helpers class

Constructors

Helpers()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

now → int
now
no setter

Static Methods

decodeBech32(String bech32String) → List<String>
Decode a bech32 string into a hex string + human readable part
encodeBech32(String hex, String hrp) → String
Encode a hex string + human readable part as a bech32 string
getEventsFromTags(List tag) → List<String>
reads tags from a nostr event and returns a list of events
getPubkeysFromTags(List tag) → List<String>
reads tags from a nostr event and returns a list of pubkeys
getRandomString(int length) → String
return a random string of given length
getSecureRandomHex(int length) → String
return a secure random hex string of given length
isBlank(String? str) → bool
return if given string is blank
isNotBlank(String? str) → bool
return if given string is not blank