KeyPair class

Constructors

KeyPair(String? privateKey, String publicKey, String? privateKeyBech32, String? publicKeyBech32)
KeyPair.justPublicKey(String publicKey)

Properties

hashCode → int
The hash code for this object.
no setteroverride
privateKey ↔ String?
privateKey is a 32-bytes hex-encoded string
getter/setter pair
privateKeyBech32 ↔ String?
privateKeyBech32 is a human readable private key e.g. nsec
getter/setter pair
publicKey → String
publicKey is a 32-bytes hex-encoded string
final
publicKeyBech32 ↔ String?
publicKeyBech32 is a human readable public key e.g. npub
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override