Nip19Decoder class

NIP-19 decoding functions

Constructors

Nip19Decoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(String nip19String) → String
Decode a NIP-19 encoded string (npub, note, nevent, nprofile, naddr) Returns the decoded hex string
decodeNaddr(String naddrStr) → Naddr
Decode naddr and return Naddr object
decodeNevent(String neventStr) → Nevent
Decode nevent and return Nevent object
decodeNprofile(String nprofileStr) → Nprofile
Decode nprofile and return Nprofile object