PqKeyPair class
An ML-KEM-1024 keypair derived from a BIP-39 seed.
secretKey is long-term secret material. Treat it the way you would treat the seed itself.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited