UploadProgress class

Upload progress information

Constructors

UploadProgress({required int sentBytes, required int totalBytes, bool isComplete = false, Response? response, Object? error})

Properties

error Object?
final
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
final
percentage double
no setter
progress double
no setter
response → Response?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentBytes int
final
totalBytes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited