computeFileHash abstract method
Computes SHA256 hash of a file by reading it in chunks Returns stream updates with progress and a final event containing FileHashProgress.hash
Implementation
Stream<FileHashProgress> computeFileHash(String filePath);
Computes SHA256 hash of a file by reading it in chunks Returns stream updates with progress and a final event containing FileHashProgress.hash
Stream<FileHashProgress> computeFileHash(String filePath);