RustEventVerifier class
An implementation of EventVerifier that uses native Rust for event verification.
This class provides a bridge between Dart and Rust via FFI using native assets, allowing for efficient verification of Nostr events using Rust's performance capabilities.
- Implemented types
Constructors
- RustEventVerifier()
- Creates a new instance of RustEventVerifier.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
Nip01Event event) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited