DecryptedEventPayloadRecord class
Sidecar cache record for decrypted event plaintext.
NDK intentionally does not mutate the original encrypted Nip01Event with
decrypted content. Instead it stores a separate plaintext sidecar keyed by
(eventId, viewerPubKey).
Constructors
- DecryptedEventPayloadRecord({required String eventId, required String viewerPubKey, DecryptedPayloadScheme scheme = DecryptedPayloadScheme.unknown, DecryptedPayloadStatus status = DecryptedPayloadStatus.ready, String? plaintextContent, required int createdAt, required int updatedAt, int? decryptedAt, String? failureReason, String? sourceEventPubKey, int? sourceEventKind})
-
const
-
DecryptedEventPayloadRecord.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → int
-
final
- decryptedAt → int?
-
final
- eventId → String
-
final
- failureReason → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Stable primary key used by cache backends.
no setter
- plaintextContent → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → DecryptedPayloadScheme
-
final
- sourceEventKind → int?
-
final
- sourceEventPubKey → String?
-
final
- status → DecryptedPayloadStatus
-
final
- updatedAt → int
-
final
- viewerPubKey → String
-
final
Methods
-
copyWith(
{String? eventId, String? viewerPubKey, DecryptedPayloadScheme? scheme, DecryptedPayloadStatus? status, Object? plaintextContent = _noChange, int? createdAt, int? updatedAt, Object? decryptedAt = _noChange, Object? failureReason = _noChange, Object? sourceEventPubKey = _noChange, Object? sourceEventKind = _noChange}) → DecryptedEventPayloadRecord -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited