Nip17FileMetadata class
Parsed metadata carried only inside a NIP-17 kind-15 rumor.
Constructors
- Nip17FileMetadata({required Uri url, required String mimeType, required String encryptionAlgorithm, required String decryptionKey, required String decryptionNonce, required String encryptedSha256, required String originalSha256, int? size, String? dimensions})
-
const
- Nip17FileMetadata.fromEncryptedFile({required Uri url, required String mimeType, required Nip17EncryptedFile encryptedFile, String? dimensions})
-
factory
Properties
- decryptionKey → String
-
final
- decryptionNonce → String
-
final
- dimensions → String?
-
final
- encryptedSha256 → String
-
final
- encryptionAlgorithm → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String
-
final
- originalSha256 → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int?
-
final
- url → Uri
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTags(
) → List< List< String> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
Nip01Event rumor) → Nip17FileMetadata? - Parses a kind-15 rumor, rejecting missing or duplicated required tags.