Nip85AddressableMetrics class
Addressable event metrics result from a NIP-85 assertion (kind 30384)
Constructors
-
Nip85AddressableMetrics({required String eventAddress, required String providerPubkey, required int createdAt, required Map<
Nip85Metric, dynamic> metrics})
Properties
- commentCount → int?
-
Get comment count
no setter
- createdAt → int
-
Timestamp of the assertion
final
- eventAddress → String
-
Subject event address (kind:pubkey:d-tag)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metrics
→ Map<
Nip85Metric, dynamic> -
Map of metric values
final
- providerPubkey → String
-
Provider pubkey (who made the assertion)
final
- quoteCount → int?
-
Get quote count
no setter
- rank → int?
-
Get rank (0-100)
no setter
- reactionCount → int?
-
Get reaction count
no setter
- repostCount → int?
-
Get repost count
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zapAmount → int?
-
Get zap amount
no setter
- zapCount → int?
-
Get zap count
no setter
Methods
-
getMetric<
T> (Nip85Metric metric) → T? - Get a specific metric value
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited