Nip85UserMetrics class
User metrics result from a NIP-85 assertion (kind 30382)
Constructors
-
Nip85UserMetrics({required String pubkey, required String providerPubkey, required int createdAt, required Map<
Nip85Metric, dynamic> metrics, List<String> topics = const []})
Properties
- createdAt → int
-
Timestamp of the assertion
final
- firstCreatedAt → int?
-
Get first created at timestamp
no setter
- firstSeenAt → int?
-
Get first seen at timestamp
no setter
- followers → int?
-
Get follower count
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metrics
→ Map<
Nip85Metric, dynamic> -
Map of metric values
final
- postCount → int?
-
Get post count
no setter
- providerPubkey → String
-
Provider pubkey (who made the assertion)
final
- pubkey → String
-
Subject pubkey (the user being asserted about)
final
- rank → int?
-
Get rank (0-100)
no setter
- reactionsCount → int?
-
Get reactions count
no setter
- replyCount → int?
-
Get reply count
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topics
→ List<
String> -
Common topics (t tags)
final
- zapAmountReceived → int?
-
Get zap amount received (sats)
no setter
- zapAmountSent → int?
-
Get zap amount sent (sats)
no setter
- zapCountReceived → int?
-
Get zap count received
no setter
- zapCountSent → int?
-
Get zap count sent
no setter
Methods
-
getMetric<
T> (Nip85Metric metric) → T? - Get a specific metric value
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited