markSent method
void
markSent()
The request is on its way to the relay again, so whatever ended it the last time no longer holds.
Implementation
void markSent() {
if (!_receivedClosed &&
_closedMessage == null &&
!_connectionGone &&
!_retryingAuth) {
return;
}
_receivedClosed = false;
_closedMessage = null;
_connectionGone = false;
_retryingAuth = false;
onOutcomeChanged?.call();
}