onOutcomeChanged property
void Function()?
onOutcomeChanged
getter/setter pair
called by the owning RequestState whenever a field the outcome is derived from changes, so the outcome never has to be derived on read
Implementation
void Function()? onOutcomeChanged;