retryingAuth property
bool
get
retryingAuth
set while this connection authenticates to satisfy the request: the relay closed it, but it is on its way back and must not count as finished
Implementation
bool get retryingAuth => _retryingAuth;
set
retryingAuth
(bool value)
Implementation
set retryingAuth(bool value) {
if (_retryingAuth == value) return;
_retryingAuth = value;
onOutcomeChanged?.call();
}