retryingAuth property

bool retryingAuth
getter/setter pair

set while this connection authenticates to satisfy the request: the relay closed it, but it is on its way back and must not count as finished

Implementation

bool retryingAuth = false;