SoftwareApp class
Constructors
-
SoftwareApp({required SoftwareAppRef ref, required String name, required String description, required String? summary, required String? iconUrl, required List<
String> imageUrls, required List<String> platforms, required Nip01Event event}) -
const
- SoftwareApp.fromEvent(Nip01Event event)
-
factory
Properties
- description → String
-
final
- event → Nip01Event
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconUrl → String?
-
final
-
imageUrls
→ List<
String> -
final
- name → String
-
final
-
platforms
→ List<
String> -
final
- ref → SoftwareAppRef
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited