SoftwareAsset class
Constructors
-
SoftwareAsset({required String identifier, required String version, required String mimeType, required String sha256, required List<
String> urls, required int? size, required List<String> platforms, required int? minPlatformVersion, required int? versionCode, required int? minAllowedVersionCode, required List<String> certificateHashes, required String? variant, required Nip01Event event}) -
const
- SoftwareAsset.fromEvent(Nip01Event event)
-
factory
Properties
-
certificateHashes
→ List<
String> -
final
- event → Nip01Event
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- mimeType → String
-
final
- minAllowedVersionCode → int?
-
final
- minPlatformVersion → int?
-
final
-
platforms
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
final
- size → int?
-
final
- url → String?
-
no setter
-
urls
→ List<
String> -
final
- variant → String?
-
final
- version → String
-
final
- versionCode → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited