SoftwareRelease class
Constructors
-
SoftwareRelease({required String identifier, required String version, required String channel, required String releaseNotes, required List<
SoftwareAssetRef> assets, required Nip01Event event}) -
const
- SoftwareRelease.fromEvent(Nip01Event event)
-
factory
Properties
-
assets
→ List<
SoftwareAssetRef> -
final
- channel → String
-
final
- event → Nip01Event
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- releaseNotes → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited