domain_layer/entities/wallet/wallet library
Classes
- Wallet
- Base interface for all wallet types Provides common properties and methods that all wallets must implement
Enums
- WalletPaymentProtocol
- Lightning payment protocols a wallet can use for internal transfers.