WalletTransaction class abstract
- Implementers
- Available extensions
Constructors
-
WalletTransaction({required String id, required String walletId, required int changeAmount, required String unit, required WalletType walletType, required WalletTransactionState state, required Map<
String, dynamic> metadata, String? completionMsg, int? transactionDate, int? initiatedDate})
Properties
- changeAmount → int
-
positive for incoming, negative for outgoing
final
- completionMsg → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- initiatedDate ↔ int?
-
Date in milliseconds since epoch
getter/setter pair
-
metadata
→ Map<
String, dynamic> -
metadata to store additional information for the specific transaction type
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → WalletTransactionState
-
final
- transactionDate ↔ int?
-
Date in milliseconds since epoch
getter/setter pair
- unit → String
-
final
- walletId → String
-
final
- walletType → WalletType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonForStorage(
) → Map< String, Object?> -
Available on WalletTransaction, provided by the WalletTransactionExtension extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
toTransactionType(
{required String id, required String walletId, required int changeAmount, required String unit, required WalletType walletType, required WalletTransactionState state, required Map< String, dynamic> metadata, String? completionMsg, int? transactionDate, int? initiatedDate, String? token, List<String> ? proofPubKeys}) → WalletTransaction -
constructs the concrete wallet type based on the type string
metadata is used to provide additional information required for the wallet type