Downloads a blob directly to a file path
For web: triggers browser download dialog with the file
For native: saves to the file system at the given path
Gets a blob by trying servers sequentially until success
If authorization is null, the server must be public
If start and end are null, the entire blob is returned
start and end are used to download a range of bytes, @see MDN HTTP range requests
checks if the server supports range requests, if no server supports range requests, the entire blob is returned
otherwise, the blob is returned in chunks. @see MDN HTTP range requests
Mirrors a blob from one server to another using the /mirror endpoint
fileUrl is the source URL where the blob exists
serverUrl is the target server to mirror to
sha256 is the hash of the blob
authorization is the signed authorization event
Checks if the server supports range requests and gets the content length
first value is whether the server supports range requests
second value is the content length of the blob in bytes
Uploads a blob from a file path using the specified strategy
Reads the file in chunks to minimize memory usage
For web: prompts user to select a file via File System Access API
For native: filePath is the actual file system path
Returns a stream of progress updates