removeContactList abstract method
- @Deprecated('Use removeEvents(pubKeys: ..., kinds: [ContactList.kKind]); ContactList is now a convenience view over the generic event cache.')
- String pubKey
Implementation
@Deprecated(
'Use removeEvents(pubKeys: ..., kinds: [ContactList.kKind]); ContactList is now a convenience view over the generic event cache.',
)
Future<void> removeContactList(String pubKey);