removeMetadata abstract method
- @Deprecated('Use removeEvents(pubKeys: ..., kinds: [Metadata.kKind]); Metadata is now a convenience view over the generic event cache.')
- String pubKey
Implementation
@Deprecated(
'Use removeEvents(pubKeys: ..., kinds: [Metadata.kKind]); Metadata is now a convenience view over the generic event cache.',
)
Future<void> removeMetadata(String pubKey);