EventSigner class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pendingRequests
→ List<
PendingSignerRequest> -
Current list of pending requests (synchronous snapshot).
no setter
-
pendingRequestsStream
→ Stream<
List< PendingSignerRequest> > -
Stream of pending requests waiting for user approval.
Emits whenever the list changes (request added, completed, or cancelled).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelRequest(
String requestId) → bool - Cancel a pending request by its ID.
-
canSign(
) → bool -
decrypt(
String msg, String destPubKey, {String? id}) → Future< String?> -
decryptNip44(
{required String ciphertext, required String senderPubKey}) → Future< String?> -
dispose(
) → Future< void> - Dispose of resources used by the signer.
-
encrypt(
String msg, String destPubKey, {String? id}) → Future< String?> -
encryptNip44(
{required String plaintext, required String recipientPubKey}) → Future< String?> -
getPublicKey(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
Nip01Event event) → Future< Nip01Event> - Signs the given event and returns the signed event
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited