PayRequest class

Request to pay a Lightning instruction from a BIP-321 URI.

Inheritance

Constructors

PayRequest({required String payment, int? amountMsat, int? maxFeeMsat, String? payerNote, Map<String, dynamic>? metadata})
const

Properties

amountMsat int?
The amount to pay in millisatoshis when the instruction has no amount.
final
hashCode int
The hash code for this object.
no setterinherited
maxFeeMsat int?
The maximum routing fee the sender is willing to pay, in millisatoshis.
final
metadata Map<String, dynamic>?
Optional application-defined metadata.
final
method NwcMethod
finalinherited
payerNote String?
An optional message from the payer.
final
payment String
The BIP-321 payment URI.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited