WalletTransferResult class
Result of a completed or submitted wallet-to-wallet transfer.
Constructors
- WalletTransferResult({required String sourceWalletId, required String destinationWalletId, required WalletPaymentProtocol protocol, required String payment, ReceiveResponse? receiveResponse, PayResponse? payResponse, PayInvoiceResponse? payInvoiceResponse})
-
const
Properties
- destinationWalletId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- payInvoiceResponse → PayInvoiceResponse?
-
final
- payment → String
-
final
- payResponse → PayResponse?
-
final
- protocol → WalletPaymentProtocol
-
final
- receiveResponse → ReceiveResponse?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceWalletId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited