ndk library
Classes
- Account
- Account entity
- Accounts
- A usecase that handles accounts
- Bip340EventSigner
- Pure Dart Event Signer
- Bip340EventVerifier
- Pure dart event verifier using https://pub.dev/packages/bip340 can be slow on mobile devices
- BlobDeleteResult
- Result of a blob delete
- BlobDescriptor
- Descriptor of a blob - when getting a blob from a server
- BlobNip94
-
BUD-08
is BlobNip94 because fromJson does not work with nostr events, only blobDescriptor! - BlobResponse
- Response of a blob download
- BlobUploadProgress
- Progress information for blob uploads
- BlobUploadResult
- Result of a blob upload
- Blossom
-
direct access usecase to blossom
use files usecase for a more convinent way to manage files - BlossomUserServerList
- Blossom User Server List used to manage the blossom servers of a user
- Broadcast
-
class for low level nostr broadcasts / publish
wraps the engines to inject singer - BunkerConnection
- Bunkers
- Bunkers usecase that handles NIP-46 remote signing protocol operations
- CacheManager
- ConsoleOutput
- Console output with color support
- ContactList
- nip02 contact list
- EventFilter
-
A class that filters events
Used to clean event streams based on the event - EventSigner
- EventVerifier
- FetchedRanges
- Usecase to track and query fetched ranges per relay
- FetchedRangesGap
- A gap in fetched ranges (missing time range)
- FileHashProgress
- Files
- high level usecase to manage files on nostr
- Filter
- Represents a filter for querying Nostr events.
- FilterFetchedRangeRecord
- Record stored in the database for filter fetched ranges
- FilterFingerprint
- Utility to generate a hash for a filter (excluding temporal fields)
- Follows
- Follows usecase
- GetBalanceResponse
- Represents the result of a 'get_balance' response.
- GetInfoResponse
- Represents the result of a 'get_info' response.
- GiftWrap
- InvoiceResponse
- invoice response
- JitEngine
- Just In Time Network Engine This engine is responsible for handling all nostr network requests
- Lists
- Lists usecase for access to NIP-51 lists and sets.
- ListTransactionsResponse
- Represents the result of a 'list_transactions' response.
- Logger
- A mixin class that provides a logger instance.
- LogLevels
- A class that provides log levels.
- LogOutput
- Abstract interface for logger outputs.
- LookupInvoiceResponse
- Represents the result of a 'lookup_invoice' response.
- MakeInvoiceResponse
- Represents the result of a 'make_invoice' response.
- MemCacheManager
- In memory database implementation benefits: very fast drawbacks: does not persist
- Metadata
- basic nostr metadata
- Metadatas
- nostr metadata usecase
- Ndk
- Main entry point for the NDK (Nostr Development Kit) library.
- NdkBroadcastResponse
- the response to a low level broadcast request
- NdkConfig
- Configuration class for the Nostr Development Kit (NDK)
- NdkLogger
- Core logger implementation.
- NdkRequest
- Ndk request
- NdkResponse
- Represents a response from a Nostr Development Kit (NDK) request.
- Nip01Event
- basic nostr nip01 event data structure
- Nip01EventModel
- Data model for NIP-01 Event Extends Nip01Event entity with serialization methods to/from JSON and other formats
- Nip01Utils
- Nip19
- Main NIP-19 class providing encoding, decoding, and validation This is a facade that delegates to specialized encoder/decoder classes
- Nip19Decoder
- NIP-19 decoding functions
- Nip19Encoder
- NIP-19 encoding functions
- Nip19TLV
- TLV (Type-Length-Value) parsing for NIP-19
- Nip19Utils
- Utility functions for NIP-19
- Nip51List
- Nip51ListElement
- Nip51Set
- NostrConnect
- NotCoveredPubKey
- Nwc
- Main entry point for the NWC (Nostr Wallet Connect - NIP47 ) usecase
- NwcConnection
- NWC Connection
- PayInvoiceResponse
- Represents the result of an pay_invoice response.
- PendingSignerRequest
- Represents a pending request waiting for user approval on a signer.
- ProofOfWork
- PTagCountEventFilter
- filter for too many tags useful for preventing hellthreads
- Relay
- Basic relay info/status
- RelayFetchedRanges
- Fetched ranges information for a specific relay and filter combination
- RelaySet
- RelaySets
- Requests
- A class that handles low-level Nostr network requests and subscriptions.
- RustEventVerifier
- Stub implementation of RustEventVerifier for platforms that don't support FFI (e.g., web).
- Search
- TimeRange
- A time range that has been fetched from a relay
- TransactionResult
- Represents a transaction result.
- UserRelayLists
-
similar to nip65, but also accepts values from nip02
gives you inbox/outbox data in various ways
UserRelayList is a mapping of pubkey to relays with read/write markers UserRelayLists is a usecase for managing UserRelayLists - ZapReceipt
- ZapRequest
- Zap Request
- ZapResponse
- zap response
- Zaps
- Zaps
Enums
- AccountType
- LogLevel
- Log levels for the NDK logger.
- NdkEngine
- Enum representing different engine modes for Nostr network operations.
- RelayDirection
- SignerMethod
- Methods that can be called on a signer
- UploadPhase
- UploadStrategy
Exceptions / Errors
- InvalidPadding
- SignerRequestCancelledException
- Exception thrown when a signer request is cancelled by the user.
- SignerRequestRejectedException
- Exception thrown when a signer request is rejected by the remote signer.