pendingDeliveryRetriesEnabled property

bool pendingDeliveryRetriesEnabled
getter/setter pair

Whether persisted broadcast deliveries are retried automatically in the background.

Disable this for short-lived clients such as command-line tools that should only perform the network work requested by the current command.

Implementation

bool pendingDeliveryRetriesEnabled;