BoundedLruSet<T> class
A fixed-capacity set that evicts the least recently added or touched value.
Constructors
- BoundedLruSet({required int maxSize})
Properties
Methods
-
add(
T value) → bool -
Adds or touches
value, returning whether it was not already retained. -
contains(
T value) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
T value) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited