BoundedLruSet<T> class

A fixed-capacity set that evicts the least recently added or touched value.

Constructors

BoundedLruSet({required int maxSize})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(T value) → bool
Adds or touches value, returning whether it was not already retained.
contains(T value) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(T value) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited