respond static method
Reconciles a message received from an initiator, as the responding side.
Only the initiator learns the have/need sets, so this returns just the response message.
Implementation
static Uint8List respond(Uint8List message, List<NegentropyItem> items) {
return _reconcileAux(
message,
items,
isInitiator: false,
needIds: [],
haveIds: [],
);
}